# Testing and Verification

Torii has a built-in simulation framework, as well as first-class formal verification support. As well as Python {py:mod}`unittest` integration for ease of setting up testing.

```{toctree}
:maxdepth: 2

simulation
formal
```

```{eval-rst}
.. automodule:: torii.test
   :members:

```
